use std::time::Duration;

use config::Config;
use tokio::time;
use tracing::debug;

use crate::json::alert::Alert;

pub mod alert_swiss;
pub mod cli;
pub mod config;
mod json {
    pub mod alert;
    pub mod alerts;
    pub mod area;
    pub mod circle;
    pub mod contact;
    pub mod coordinate;
    pub mod datetime;
    pub mod description;
    pub mod image;
    pub mod image_description;
    pub mod image_title;
    pub mod link;
    pub mod polygon;
    pub mod region;
    pub mod text;
    pub mod title;
}
pub mod logging;

pub async fn run(config: Config) {
    let mut interval = time::interval(Duration::from_secs(config.interval));

    loop {
        interval.tick().await;
        let alerts = alert_swiss::fetch_alerts().await.unwrap();
        let new_alerts: Vec<Alert> = alerts.list.into_iter().filter(|x| true).collect();

        debug!("{new_alerts:#?}");
    }
}
